@@ -1,47 +1,47 @@
 $VAR1 = {
-          'mod' => 'n',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'scriptAlias' => 'perl',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
           'database' => {
-                          'CurrentPass' => '',
-                          'user' => 'root',
-                          'host' => 'localhost',
-                          'name' => 'LZE',
+                          'CurrentHost' => 'localhost',
                           'CurrentUser' => 'root',
                           'CurrentDb' => 'LZE',
-                          'password' => '',
-                          'CurrentHost' => 'localhost'
+                          'user' => 'root',
+                          'name' => 'LZE',
+                          'host' => 'localhost',
+                          'CurrentPass' => 'keinz',
+                          'password' => 'keinz'
                         },
-          'files' => {
-                       'owner' => 'lze',
-                       'chmod' => '0755',
-                       'group' => 'lze'
-                     },
+          'version' => '0.85',
+          'mod' => 1,
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'language' => 'en',
+          'cgi' => {
+                     'style' => 'mysql',
+                     'bin' => '/var/www/cgi-bin',
+                     'serverName' => 'localhost',
+                     'cookiePath' => '/',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'alias' => 'perl',
+                     'title' => 'MySQL::Admin',
+                     'expires' => '+1y'
+                   },
           'floodtime' => 10,
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
           'admin' => {
                        'email' => 'your@email.org',
                        'password' => 'testpass'
                      },
-          'language' => 'en',
-          'cgi' => {
-                     'expires' => '+1y',
-                     'bin' => 'cgi-bin',
-                     'cookiePath' => '/',
-                     'serverName' => 'localhost',
-                     'DocumentRoot' => 'htdocs',
-                     'style' => 'mysql',
-                     'alias' => 'cgi-bin',
-                     'title' => 'MySQL::Admin'
-                   },
-          'scriptAlias' => 'cgi-bin',
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'lze',
+                       'owner' => 'lze'
+                     },
           'uploads' => {
-                         'maxlength' => 21000000,
                          'chmod' => 438,
+                         'maxlength' => 21000000,
                          'path' => '/var/www/htdocs/download'
                        },
-          'actions' => 'cgi-bin/config/actions.pl',
-          'config' => 'cgi-bin/config/settings.pl',
-          'translate' => 'cgi-bin/config/translate.pl',
-          'session' => 'cgi-bin/config/session.pl',
-          'version' => '0.84'
+          'translate' => '/var/www/cgi-bin/config/translate.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
