@@ -52,7 +52,7 @@ $VAR1 = {
                     'analyzetable' => 'Analyze Table',
                     'processlist' => 'Processes',
                     'showsqlsearch' => 'Search in DB',
-                    'links_pro_page' => 'links/page',
+                    'links_pro_page' => 'Links/Page',
                     'selected' => 'Select all',
                     'logout' => 'Logout',
                     'exportdatabase' => 'Database',
