@@ -8,12 +8,12 @@ use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $sStyle $bModPerl)
 @ISA                          = qw(Exporter);
 @Template::Quick::EXPORT      = qw(initTemplate appendHash Template initArray);
 %Template::Quick::EXPORT_TAGS = ('all' => [qw(initTemplate appendHash Template initArray  )]);
-$Template::Quick::VERSION     = '0.84';
+$Template::Quick::VERSION     = '0.85';
 $DefaultClass                 = 'Template::Quick' unless defined $Template::Quick::DefaultClass;
 our %tmplate;
 $sStyle      = 'mysql';
 $bModPerl   = ($ENV{MOD_PERL}) ? 1 : 0;
-$defaultconfig = 'cgi-bin//config/settings.pl';
+$defaultconfig = '/var/www/cgi-bin/config/settings.pl';
 
 =head1 NAME
 
