@@ -301,7 +301,7 @@ function submitForm(node,tabId,tabTitle,bHistory,method,uri)
 {
     bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
     method   = typeof method   !== 'undefined' ? method   : 'POST';
-    var url  = typeof uri      !== 'undefined' ? uri      : "%ALIAS%/mysql.pl?";
+    var url  = typeof uri      !== 'undefined' ? uri      : "perl/mysql.pl?";
     if(checkForm(node)){
       var formData = new FormData();
       for(var i =0; i < node.elements.length;i++){
@@ -344,7 +344,7 @@ function submitForm(node,tabId,tabTitle,bHistory,method,uri)
 }
 var http_request = false;
 var oldpage;
-//requestURI('%ALIAS%/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+//requestURI('perl/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
 function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 {
       closePopup();
@@ -482,9 +482,9 @@ function loadHistory()
     var uri = RegExp.$1;
     var url = window.location.search;
     if(uri && action){
-	requestURI('%ALIAS%/mysql.pl'+uri,action,action,false);
+	requestURI('perl/mysql.pl'+uri,action,action,false);
     }else
-      requestURI('%ALIAS%/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
+      requestURI('perl/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
     return true;
 }
 
